@@ -61,7 +61,8 @@ class TimestreamLoader(TimestreamReader):
         capture_time: datetime,
         source: str = None,
         upsert: bool = False,
-        ignore_parse_error: bool = True
+        ignore_parse_error: bool = True,
+
     ) -> dict:
         '''
         Performs a Timestream load. Validates the input and parses the data into Timestream records.
@@ -116,7 +117,7 @@ class TimestreamLoader(TimestreamReader):
 
         # Batch the accepted records by common dimensions
         self._logger.info('starting batching...')
-        self._logger.info(f"MIN COMMON TSLOADER {self.__min_common_dimensions}")
+        self._logger.info(f"BATCH {self.__max_batch_size} MIN {self.__min_common_dimensions}")
         batches = batch_records(
             result.accepted_records,
             max_batch_size=self.__max_batch_size,
